@@ -13,10 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
+from oslo.config import cfg
 
 from sahara.conductor import api as conductor_api
-from sahara.i18n import _
 
 
 def Api(use_local=True, **kwargs):
@@ -28,8 +27,7 @@ def Api(use_local=True, **kwargs):
     if cfg.CONF.conductor.use_local or use_local:
         api = conductor_api.LocalApi
     else:
-        raise NotImplementedError(
-            _("Remote conductor isn't implemented yet."))
+        raise NotImplementedError("Remote conductor isn't implemented yet.")
         # api = conductor.RemoteApi
 
     return api(**kwargs)
