@@ -15,15 +15,25 @@
 
 """Base class for classes that need modular database access."""
 
-from oslo_config import cfg
-from oslo_utils import importutils
+from oslo.config import cfg
 
+from sahara.openstack.common import importutils
+
+
+db_driver_opt = cfg.StrOpt('db_driver',
+                           default='sahara.db',
+                           help='Driver to use for database access.')
 
 CONF = cfg.CONF
+CONF.register_opt(db_driver_opt)
 
 
 class Base(object):
     """DB driver is injected in the init method."""
 
     def __init__(self):
-        self.db = importutils.try_import(CONF.db_driver)
+        self.db = importutils.import_module(CONF.db_driver)
+
+
+def is_mysql_avail():
+    return CONF.database.connection.startswith('mysql')
