@@ -13,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
-from sahara import conductor as c
+from sahara import conductor
 from sahara import context
-from sahara import exceptions as base_exc
-from sahara.i18n import _
-from sahara.i18n import _LI
-from sahara.plugins import exceptions as ex
+from sahara import exceptions as exc
+from sahara.openstack.common import log as logging
+from sahara.plugins.general import exceptions as ex
+from sahara.plugins.general import utils as u
 from sahara.plugins.hdp import hadoopserver as h
 from sahara.plugins.hdp import saharautils as utils
 from sahara.plugins.hdp.versions import versionhandlerfactory as vhf
 from sahara.plugins import provisioning as p
 from sahara.topology import topology_helper as th
-from sahara.utils import cluster_progress_ops as cpo
 
 
-conductor = c.API
+conductor = conductor.API
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
@@ -67,41 +65,10 @@ class AmbariPlugin(p.ProvisioningPluginBase):
         # enabled
         self._configure_topology_for_cluster(cluster, servers)
 
-        LOG.info(_LI("Install of Hadoop stack successful."))
+        LOG.info("Install of Hadoop stack successful.")
         # add service urls
         self._set_cluster_info(cluster, cluster_spec)
 
-        # check if HDFS HA is enabled; set it up if so
-        if cluster_spec.is_hdfs_ha_enabled(cluster):
-            self.configure_hdfs_ha(cluster)
-
-    @cpo.event_wrapper(
-        True, step=_("Add configurations to cluster"), param=('cluster', 1))
-    def configure_hdfs_ha(self, cluster):
-        LOG.debug("Configuring HDFS HA")
-        version = cluster.hadoop_version
-        handler = self.version_factory.get_version_handler(version)
-
-        cluster_spec = handler.get_cluster_spec(
-            cluster, self._map_to_user_inputs(
-                version, cluster.cluster_configs))
-        hosts = self._get_servers(cluster)
-        ambari_info = self.get_ambari_info(cluster_spec)
-        self.cluster_ambari_mapping[cluster.name] = ambari_info
-        rpm = self._get_rpm_uri(cluster_spec)
-
-        servers = []
-        for host in hosts:
-            host_role = utils.get_host_role(host)
-            servers.append(
-                h.HadoopServer(host, cluster_spec.node_groups[host_role],
-                               ambari_rpm=rpm))
-
-        ambari_client = handler.get_ambari_client()
-        ambari_client.setup_hdfs_ha(cluster_spec, servers, ambari_info,
-                                    cluster.name)
-        LOG.info(_LI("Configure HDFS HA successful."))
-
     def _get_servers(self, cluster):
         servers = []
         if hasattr(cluster, 'node_groups') and cluster.node_groups is not None:
@@ -128,6 +95,9 @@ class AmbariPlugin(p.ProvisioningPluginBase):
 
         return node_processes
 
+    def get_hdfs_user(self):
+        return 'hdfs'
+
     def convert(self, config, plugin_name, version, template_name,
                 cluster_template_create):
         handler = self.version_factory.get_version_handler(version)
@@ -157,9 +127,9 @@ class AmbariPlugin(p.ProvisioningPluginBase):
                 service_dict[ci.name] = entry.value
                 cluster_configs[target] = service_dict
             else:
-                LOG.debug('Template based input "{entry_name}" is being'
-                          ' filtered out as it is not considered a user input'
-                          .format(entry_name=entry.config.name))
+                LOG.debug('Template based input "{0}" is being filtered out as'
+                          ' it is not considered a user input'
+                          .format(entry.config.name))
 
         ctx = context.ctx()
         return cluster_template_create(ctx,
@@ -169,29 +139,34 @@ class AmbariPlugin(p.ProvisioningPluginBase):
                                         "node_groups": node_groups,
                                         "cluster_configs": cluster_configs})
 
+    def get_oozie_server(self, cluster):
+        return u.get_instance(cluster, "oozie_server")
+
+    def get_resource_manager_uri(self, cluster):
+        version_handler = (
+            self.version_factory.get_version_handler(cluster.hadoop_version))
+        return version_handler.get_resource_manager_uri(cluster)
+
     def update_infra(self, cluster):
         pass
 
     def convert_props_to_template(self, props):
         raise NotImplementedError('not yet supported')
 
+    def _spawn(self, description, func, *args, **kwargs):
+        context.spawn(description, func, *args, **kwargs)
+
     def _provision_cluster(self, name, cluster_spec, ambari_info,
                            servers, version):
-        # TODO(jspeidel): encapsulate in another class
+        #TODO(jspeidel): encapsulate in another class
 
-        if servers:
-            cpo.add_provisioning_step(
-                servers[0].cluster_id,
-                _("Provision cluster via Ambari"), len(servers))
+        LOG.info('Provisioning Cluster via Ambari Server: {0} ...'.format(
+            ambari_info.get_address()))
 
-        with context.ThreadGroup() as tg:
-            for server in servers:
-                with context.set_current_instance_id(
-                        server.instance['instance_id']):
-                    tg.spawn(
-                        "hdp-provision-instance-%s" %
-                        server.instance.hostname(),
-                        server.provision_ambari, ambari_info, cluster_spec)
+        for server in servers:
+            self._spawn(
+                "hdp-provision-instance-%s" % server.instance.hostname(),
+                server.provision_ambari, ambari_info, cluster_spec)
 
         handler = self.version_factory.get_version_handler(version)
         ambari_client = handler.get_ambari_client()
@@ -202,15 +177,12 @@ class AmbariPlugin(p.ProvisioningPluginBase):
         ambari_client.provision_cluster(
             cluster_spec, servers, ambari_info, name)
 
-        LOG.info(_LI('Cluster provisioned via Ambari Server: {server_ip}')
-                 .format(server_ip=ambari_info.get_address()))
-
-    # TODO(jspeidel): invoke during scale cluster.  Will need to handle dups
+    #TODO(jspeidel): invoke during scale cluster.  Will need to handle dups
     def _set_cluster_info(self, cluster, cluster_spec):
         info = {}
         for service in cluster_spec.services:
             if service.deployed:
-                service.register_service_urls(cluster_spec, info, cluster)
+                service.register_service_urls(cluster_spec, info)
 
         conductor.cluster_update(context.ctx(), cluster, {'info': info})
 
@@ -223,24 +195,24 @@ class AmbariPlugin(p.ProvisioningPluginBase):
                 is_admin_provided = False
                 admin_user = ambari_info.user
                 admin_password = ambari_info.password
-                for user in service.users:
-                    if user.name == 'admin':
+                for u in service.users:
+                    if u.name == 'admin':
                         ambari_client.update_ambari_admin_user(
-                            user.password, ambari_info)
+                            u.password, ambari_info)
                         is_admin_provided = True
                         ambari_info.user = 'admin'
-                        ambari_info.password = user.password
+                        ambari_info.password = u.password
                     else:
-                        ambari_client.add_ambari_user(user, ambari_info)
-                        if 'admin' in user.groups:
-                            admin_user = user.name
-                            admin_password = user.password
+                        ambari_client.add_ambari_user(u, ambari_info)
+                        if 'admin' in u.groups:
+                            admin_user = u.name
+                            admin_password = u.password
 
                 if not is_admin_provided:
                     if admin_user is None:
-                        raise ex.HadoopProvisionError(_("An Ambari user in the"
-                                                        " admin group must be "
-                                                        "configured."))
+                        raise ex.HadoopProvisionError("An Ambari user in the "
+                                                      "admin group must be "
+                                                      "configured.")
                     ambari_info.user = admin_user
                     ambari_info.password = admin_password
                     ambari_client.delete_ambari_user('admin', ambari_info)
@@ -257,8 +229,8 @@ class AmbariPlugin(p.ProvisioningPluginBase):
                 ambari_info.user = admin_user.name
                 ambari_info.password = admin_user.password
 
-        LOG.info(_LI('Using "{username}" as admin user for scaling of cluster')
-                 .format(username=ambari_info.user))
+        LOG.info('Using "{0}" as admin user for scaling of cluster'
+                 .format(ambari_info.user))
 
     # PLUGIN SPI METHODS:
     def get_versions(self):
@@ -283,24 +255,26 @@ class AmbariPlugin(p.ProvisioningPluginBase):
             cluster, self._map_to_user_inputs(
                 cluster.hadoop_version, cluster.cluster_configs))
 
-        try:
-            client.start_services(cluster.name, cluster_spec,
-                                  self.cluster_ambari_mapping[cluster.name])
-        finally:
-            client.cleanup(self.cluster_ambari_mapping[cluster.name])
+        client.start_services(cluster.name, cluster_spec,
+                              self.cluster_ambari_mapping[cluster.name])
+
+        client.cleanup(self.cluster_ambari_mapping[cluster.name])
 
     def get_title(self):
         return 'Hortonworks Data Platform'
 
     def get_description(self):
-        return _('The Hortonworks Sahara plugin automates the deployment '
-                 'of the Hortonworks Data Platform (HDP) on OpenStack.')
+        return ('The Hortonworks OpenStack plugin works with project '
+                'Sahara to automate the deployment of the Hortonworks data'
+                ' platform on OpenStack based public & private clouds')
 
     def validate(self, cluster):
-        raise base_exc.DeprecatedException(
-            _("The HDP 2.0.6 plugin is deprecated in Mitaka release and "
-              "will be removed in Newton release. Please, use the Ambari 2.3 "
-              "instead."))
+        # creating operational config results in validation
+        handler = self.version_factory.get_version_handler(
+            cluster.hadoop_version)
+
+        handler.get_cluster_spec(cluster, self._map_to_user_inputs(
+            cluster.hadoop_version, cluster.cluster_configs))
 
     def scale_cluster(self, cluster, instances):
         handler = self.version_factory.get_version_handler(
@@ -322,16 +296,9 @@ class AmbariPlugin(p.ProvisioningPluginBase):
         ambari_info = self.get_ambari_info(cluster_spec)
         self._update_ambari_info_credentials(cluster_spec, ambari_info)
 
-        cpo.add_provisioning_step(
-            cluster.id, _("Provision cluster via Ambari"), len(servers))
-
-        with context.ThreadGroup() as tg:
-            for server in servers:
-                with context.set_current_instance_id(
-                        server.instance['instance_id']):
-                    tg.spawn('Ambari provisioning thread',
-                             server.provision_ambari,
-                             ambari_info, cluster_spec)
+        for server in servers:
+            self._spawn('Ambari provisioning thread',
+                        server.provision_ambari, ambari_info, cluster_spec)
 
         ambari_client.configure_scaled_cluster_instances(
             cluster.name, cluster_spec, self._get_num_hosts(cluster),
@@ -343,40 +310,9 @@ class AmbariPlugin(p.ProvisioningPluginBase):
 
         ambari_client.cleanup(ambari_info)
 
-    def get_edp_engine(self, cluster, job_type):
-        version_handler = (
-            self.version_factory.get_version_handler(cluster.hadoop_version))
-        return version_handler.get_edp_engine(cluster, job_type)
-
-    def get_edp_job_types(self, versions=None):
-        res = {}
-        for vers in self.version_factory.get_versions():
-            if not versions or vers in versions:
-                vh = self.version_factory.get_version_handler(vers)
-                res[vers] = vh.get_edp_job_types()
-        return res
-
-    def get_edp_config_hints(self, job_type, version):
-        version_handler = (
-            self.version_factory.get_version_handler(version))
-        return version_handler.get_edp_config_hints(job_type)
-
     def decommission_nodes(self, cluster, instances):
-        LOG.info(_LI('AmbariPlugin: decommission_nodes called for '
-                 'HDP version = {version}')
-                 .format(version=cluster.hadoop_version))
-
-        handler = self.version_factory.get_version_handler(
-            cluster.hadoop_version)
-        ambari_client = handler.get_ambari_client()
-        cluster_spec = handler.get_cluster_spec(
-            cluster, self._map_to_user_inputs(
-                cluster.hadoop_version, cluster.cluster_configs))
-
-        ambari_info = self.get_ambari_info(cluster_spec)
-        ambari_client.decommission_cluster_instances(cluster, cluster_spec,
-                                                     instances,
-                                                     ambari_info)
+        raise exc.InvalidException('The HDP plugin does not yet support the '
+                                   'decommissioning of nodes')
 
     def validate_scaling(self, cluster, existing, additional):
         handler = self.version_factory.get_version_handler(
@@ -384,8 +320,7 @@ class AmbariPlugin(p.ProvisioningPluginBase):
 
         # results in validation
         handler.get_cluster_spec(
-            cluster, [],
-            dict(list(existing.items()) + list(additional.items())))
+            cluster, [], dict(existing.items() + additional.items()))
 
     def _get_num_hosts(self, cluster):
         count = 0
@@ -413,9 +348,6 @@ class AmbariPlugin(p.ProvisioningPluginBase):
 
     def _configure_topology_for_cluster(self, cluster, servers):
         if CONF.enable_data_locality:
-            cpo.add_provisioning_step(
-                cluster.id, _("Enable data locality for cluster"),
-                len(servers))
             topology_data = th.generate_topology_map(
                 cluster, CONF.enable_hypervisor_awareness)
             topology_str = "\n".join(
@@ -423,13 +355,8 @@ class AmbariPlugin(p.ProvisioningPluginBase):
             for server in servers:
                 server.configure_topology(topology_str)
 
-    def get_open_ports(self, node_group):
-        handler = self.version_factory.get_version_handler(
-            node_group.cluster.hadoop_version)
-        return handler.get_open_ports(node_group)
 
-
-class AmbariInfo(object):
+class AmbariInfo():
     def __init__(self, host, port, user, password):
         self.host = host
         self.port = port
@@ -438,13 +365,3 @@ class AmbariInfo(object):
 
     def get_address(self):
         return '{0}:{1}'.format(self.host.management_ip, self.port)
-
-    def is_ambari_info(self):
-        pass
-
-    def get_cluster(self):
-        sahara_instance = self.host.sahara_instance
-        return sahara_instance.cluster
-
-    def get_event_info(self):
-        return self.host.sahara_instance
