@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from sahara.i18n import _
 from sahara.plugins import provisioning as p
 from sahara.plugins.vanilla import versionfactory as vhf
 
@@ -23,14 +22,21 @@ class VanillaProvider(p.ProvisioningPluginBase):
         self.version_factory = vhf.VersionFactory.get_instance()
 
     def get_description(self):
-        return _('The Apache Vanilla plugin provides the ability to launch '
-                 'upstream Vanilla Apache Hadoop cluster without any '
-                 'management consoles. It can also deploy the Oozie '
-                 'component.')
+        return (
+            "This plugin provides an ability to launch vanilla Apache Hadoop "
+            "1.2.1 cluster without any management consoles. Also it can "
+            "deploy Oozie 4.0.0 and Hive 0.11.0")
 
     def _get_version_handler(self, hadoop_version):
         return self.version_factory.get_version_handler(hadoop_version)
 
+    def get_resource_manager_uri(self, cluster):
+        return self._get_version_handler(
+            cluster.hadoop_version).get_resource_manager_uri(cluster)
+
+    def get_hdfs_user(self):
+        return 'hadoop'
+
     def get_node_processes(self, hadoop_version):
         return self._get_version_handler(hadoop_version).get_node_processes()
 
@@ -68,31 +74,6 @@ class VanillaProvider(p.ProvisioningPluginBase):
             cluster.hadoop_version).validate_scaling(cluster, existing,
                                                      additional)
 
-    def get_edp_engine(self, cluster, job_type):
+    def get_oozie_server(self, cluster):
         return self._get_version_handler(
-            cluster.hadoop_version).get_edp_engine(cluster, job_type)
-
-    def get_edp_job_types(self, versions=[]):
-        res = {}
-        for vers in self.version_factory.get_versions():
-            if not versions or vers in versions:
-                vh = self.version_factory.get_version_handler(vers)
-                res[vers] = vh.get_edp_job_types()
-        return res
-
-    def get_edp_config_hints(self, job_type, version):
-        version_handler = (
-            self.version_factory.get_version_handler(version))
-        return version_handler.get_edp_config_hints(job_type)
-
-    def get_open_ports(self, node_group):
-        return self._get_version_handler(
-            node_group.cluster.hadoop_version).get_open_ports(node_group)
-
-    def on_terminate_cluster(self, cluster):
-        return self._get_version_handler(
-            cluster.hadoop_version).on_terminate_cluster(cluster)
-
-    def recommend_configs(self, cluster, scaling=False):
-        return self._get_version_handler(
-            cluster.hadoop_version).recommend_configs(cluster, scaling)
+            cluster.hadoop_version).get_oozie_server(cluster)
