@@ -16,10 +16,8 @@
 import os
 import re
 
-from sahara.utils import general
 
-
-class VersionFactory(object):
+class VersionFactory():
     versions = None
     modules = None
     initialized = False
@@ -28,14 +26,11 @@ class VersionFactory(object):
     def get_instance():
         if not VersionFactory.initialized:
             src_dir = os.path.join(os.path.dirname(__file__), '')
-            versions = (
+            VersionFactory.versions = (
                 [name[1:].replace('_', '.')
                  for name in os.listdir(src_dir)
                  if (os.path.isdir(os.path.join(src_dir, name))
                      and re.match(r'^v\d+_\d+_\d+$', name))])
-            versions.sort(key=general.natural_sort_key)
-            VersionFactory.versions = versions
-
             VersionFactory.modules = {}
             for version in VersionFactory.versions:
                 module_name = 'sahara.plugins.vanilla.v%s.versionhandler' % (
@@ -44,7 +39,8 @@ class VersionFactory(object):
                     __import__(module_name, fromlist=['sahara']),
                     'VersionHandler')
                 module = module_class()
-                VersionFactory.modules[version] = module
+                key = version.replace('_', '.')
+                VersionFactory.modules[key] = module
 
             VersionFactory.initialized = True
 
