@@ -13,28 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
-
 import sahara.exceptions as e
-from sahara.i18n import _
-from sahara.service.edp.job_binaries import manager as jb_manager
 from sahara.utils import api_validator as a
 
-CONF = cfg.CONF
-
-
-def is_internal_db_enabled():
-    return 'internal-db' in jb_manager.JOB_BINARIES.get_job_binaries()
-
 
 def check_job_binary_internal(data, **kwargs):
-    if not is_internal_db_enabled():
-        raise e.BadJobBinaryInternalException(
-            _("Sahara internal db is disabled for storing job binaries."))
     if not (type(data) is str and len(data) > 0):
         raise e.BadJobBinaryInternalException()
     if "name" in kwargs:
         name = kwargs["name"]
         if not a.validate_name_format(name):
-            raise e.BadJobBinaryInternalException(_("%s is not a valid name")
+            raise e.BadJobBinaryInternalException("%s is not a valid name"
                                                   % name)
