@@ -14,22 +14,19 @@
 # limitations under the License.
 
 import logging
+import socket
 import telnetlib
 import time
+import uuid
 
-import fixtures
-from keystoneclient.v2_0 import client as keystone_client
 from neutronclient.v2_0 import client as neutron_client
-from novaclient.v2 import client as nova_client
-from oslo_utils import excutils
-from oslo_utils import uuidutils
-from oslotest import base
-from saharaclient.api import base as client_base
+from novaclient.v1_1 import client as nova_client
 import saharaclient.client as sahara_client
-import six
 from swiftclient import client as swift_client
-from testtools import testcase
+import testtools
+import unittest2
 
+from sahara.openstack.common import excutils
 from sahara.tests.integration.configs import config as cfg
 import sahara.utils.openstack.images as imgs
 from sahara.utils import ssh_remote
@@ -70,78 +67,21 @@ def skip_test(config_name, message=''):
     return handle
 
 
-class ITestCase(testcase.WithAttributes, base.BaseTestCase):
+class ITestCase(testtools.TestCase, testtools.testcase.WithAttributes,
+                unittest2.TestCase):
     def setUp(self):
         super(ITestCase, self).setUp()
         self.common_config = cfg.ITConfig().common_config
-        self.plugin_config = self.get_plugin_config()
-        self._setup_clients()
-        self._setup_networks()
-        self._setup_volume_params()
-        self._setup_flavor()
-        self._setup_ssh_access()
-        self.TEST_EVENT_LOG = True
-
-        self._image_id, self._ssh_username = (
-            self.get_image_id_and_ssh_username())
+        self.vanilla_config = cfg.ITConfig().vanilla_config
+        self.vanilla_two_config = cfg.ITConfig().vanilla_two_config
+        self.hdp_config = cfg.ITConfig().hdp_config
+        self.idh2_config = cfg.ITConfig().idh2_config
+        self.idh3_config = cfg.ITConfig().idh3_config
 
         telnetlib.Telnet(
             self.common_config.SAHARA_HOST, self.common_config.SAHARA_PORT
         )
 
-    def get_plugin_config(self):
-        raise NotImplementedError
-
-    def _setup_ssh_access(self):
-        if not self.common_config.PATH_TO_SSH_KEY:
-            self.user_keypair_id = self.rand_name(
-                self.common_config.USER_KEYPAIR_ID)
-            self.private_key = self.nova.keypairs.create(
-                self.user_keypair_id).private_key
-
-        else:
-            self.user_keypair_id = self.common_config.USER_KEYPAIR_ID
-            self.private_key = open(self.common_config.PATH_TO_SSH_KEY).read()
-
-    def _setup_flavor(self):
-        if not self.common_config.FLAVOR_ID:
-            self.flavor_id = self.nova.flavors.create(
-                name=self.rand_name('i-test-flavor'),
-                ram=1024,
-                vcpus=1,
-                disk=10,
-                ephemeral=10).id
-
-        else:
-            self.flavor_id = self.common_config.FLAVOR_ID
-
-    def _setup_networks(self):
-        self.floating_ip_pool = self.common_config.FLOATING_IP_POOL
-        self.internal_neutron_net = None
-        if self.common_config.NEUTRON_ENABLED:
-            self.internal_neutron_net = self.get_internal_neutron_net_id()
-            self.floating_ip_pool = (
-                self.get_floating_ip_pool_id_for_neutron_net())
-
-    def _setup_volume_params(self):
-        self.volumes_per_node = 0
-        self.volumes_size = 0
-        if not getattr(self.plugin_config, 'SKIP_CINDER_TEST', False):
-            self.volumes_per_node = 2
-            self.volumes_size = 2
-
-    def _setup_clients(self):
-        keystone = keystone_client.Client(
-            username=self.common_config.OS_USERNAME,
-            password=self.common_config.OS_PASSWORD,
-            tenant_name=self.common_config.OS_TENANT_NAME,
-            auth_url=self.common_config.OS_AUTH_URL)
-
-        keystone.management_url = self.common_config.OS_AUTH_URL
-
-        tenant_id = [tenant.id for tenant in keystone.tenants.list()
-                     if tenant.name == self.common_config.OS_TENANT_NAME][0]
-
         self.sahara = sahara_client.Client(
             version=self.common_config.SAHARA_API_VERSION,
             username=self.common_config.OS_USERNAME,
@@ -152,7 +92,7 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
                 self.common_config.SAHARA_HOST,
                 self.common_config.SAHARA_PORT,
                 self.common_config.SAHARA_API_VERSION,
-                tenant_id
+                self.common_config.OS_TENANT_ID
             ))
 
         self.nova = nova_client.Client(
@@ -167,19 +107,35 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             tenant_name=self.common_config.OS_TENANT_NAME,
             auth_url=self.common_config.OS_AUTH_URL)
 
-# ------------------------Methods for object creation--------------------------
+        if not self.common_config.FLAVOR_ID:
+            self.flavor_id = self.nova.flavors.create(
+                name='i-test-flavor-%s' % str(uuid.uuid4())[:8],
+                ram=1024,
+                vcpus=1,
+                disk=10,
+                ephemeral=10).id
+
+        else:
+            self.flavor_id = self.common_config.FLAVOR_ID
+
+        if not self.common_config.PATH_TO_SSH_KEY:
+            self.common_config.USER_KEYPAIR_ID += str(uuid.uuid4())[:8]
+            self.private_key = self.nova.keypairs.create(
+                self.common_config.USER_KEYPAIR_ID).private_key
+
+        else:
+            self.private_key = open(self.common_config.PATH_TO_SSH_KEY).read()
+
+#-------------------------Methods for object creation--------------------------
 
     def create_node_group_template(self, name, plugin_config, description,
                                    node_processes, node_configs,
-                                   volumes_per_node=0, volumes_size=0,
-                                   floating_ip_pool=None, flavor_id=None,
-                                   **kwargs):
-        if not flavor_id:
-            flavor_id = self.flavor_id
+                                   volumes_per_node=0, volume_size=0,
+                                   floating_ip_pool=None):
         data = self.sahara.node_group_templates.create(
             name, plugin_config.PLUGIN_NAME, plugin_config.HADOOP_VERSION,
-            flavor_id, description, volumes_per_node, volumes_size,
-            node_processes, node_configs, floating_ip_pool, **kwargs)
+            self.flavor_id, description, volumes_per_node, volume_size,
+            node_processes, node_configs, floating_ip_pool)
         node_group_template_id = data.id
         return node_group_template_id
 
@@ -204,11 +160,11 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
 
         data = self.sahara.clusters.create(
             name, plugin_config.PLUGIN_NAME, plugin_config.HADOOP_VERSION,
-            cluster_template_id, self._image_id, is_transient,
+            cluster_template_id, plugin_config.IMAGE_ID, is_transient,
             description, cluster_configs, node_groups,
-            self.user_keypair_id, anti_affinity, net_id)
+            self.common_config.USER_KEYPAIR_ID, anti_affinity, net_id)
         self.cluster_id = data.id
-        return self.cluster_id
+        self.poll_cluster_state(self.cluster_id)
 
     def get_cluster_info(self, plugin_config):
         node_ip_list_with_node_processes = (
@@ -221,7 +177,7 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             with excutils.save_and_reraise_exception():
                 print(
                     '\nFailure during check of node process deployment '
-                    'on cluster node: ' + six.text_type(e)
+                    'on cluster node: ' + str(e)
                 )
 
         # For example: method "create_cluster_and_get_info" return
@@ -241,7 +197,7 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
         #               '172.18.168.242': ['namenode', 'jobtracker'],
         #               '172.18.168.167': ['datanode']
         #       },
-        #       'plugin_config': <oslo_config.cfg.GroupAttr object at 0x215d9d>
+        #       'plugin_config': <oslo.config.cfg.GroupAttr object at 0x215d9d>
         # }
         return {
             'cluster_id': self.cluster_id,
@@ -250,30 +206,24 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             'plugin_config': plugin_config
         }
 
-# --------Helper methods for cluster info obtaining and its processing---------
+#---------Helper methods for cluster info obtaining and its processing---------
 
     def poll_cluster_state(self, cluster_id):
         data = self.sahara.clusters.get(cluster_id)
         timeout = self.common_config.CLUSTER_CREATION_TIMEOUT * 60
-
-        try:
-            with fixtures.Timeout(timeout, gentle=True):
-                while True:
-                    status = str(data.status)
-                    if status == 'Active':
-                        break
-                    if status == 'Error':
-                        self.fail('Cluster state == \'Error\'.')
-
-                    time.sleep(10)
-                    data = self.sahara.clusters.get(cluster_id)
-
-        except fixtures.TimeoutException:
-            self.fail("Cluster did not return to 'Active' state "
-                      "within %d minutes." %
-                      self.common_config.CLUSTER_CREATION_TIMEOUT)
-
-        return status
+        while str(data.status) != 'Active':
+            if str(data.status) == 'Error':
+                self.fail('Cluster state == \'Error\'.')
+            if timeout <= 0:
+                self.fail(
+                    'Cluster did not return to \'Active\' state '
+                    'within %d minutes.'
+                    % self.common_config.CLUSTER_CREATION_TIMEOUT
+                )
+            data = self.sahara.clusters.get(cluster_id)
+            time.sleep(10)
+            timeout -= 10
+        return str(data.status)
 
     def get_cluster_node_ip_list_with_node_processes(self, cluster_id):
         data = self.sahara.clusters.get(cluster_id)
@@ -296,16 +246,6 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
         # }
         return node_ip_list_with_node_processes
 
-    def put_file_to_hdfs(self, namenode_ip, remote_path, data):
-        tmp_file_path = '/tmp/%s' % uuidutils.generate_uuid()[:8]
-        self.open_ssh_connection(namenode_ip)
-        self.write_file_to(tmp_file_path, data)
-        self.execute_command(
-            'sudo su - -c "hadoop dfs -copyFromLocal %s %s" %s' % (
-                tmp_file_path, remote_path, self.plugin_config.HADOOP_USER))
-        self.execute_command('rm -fr %s' % tmp_file_path)
-        self.close_ssh_connection()
-
     def try_telnet(self, host, port):
         try:
             telnetlib.Telnet(host, port)
@@ -313,7 +253,7 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
         except Exception as e:
             with excutils.save_and_reraise_exception():
                 print(
-                    '\nTelnet has failed: ' + six.text_type(e) +
+                    '\nTelnet has failed: ' + str(e) +
                     '  NODE IP: %s, PORT: %s. Passed %s minute(s).'
                     % (host, port, self.common_config.TELNET_TIMEOUT)
                 )
@@ -321,94 +261,53 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
     def get_node_info(self, node_ip_list_with_node_processes, plugin_config):
         tasktracker_count = 0
         datanode_count = 0
-        timeout = self.common_config.TELNET_TIMEOUT * 60
-        with fixtures.Timeout(timeout, gentle=True):
-            accessible = False
-            proc_with_ports = plugin_config.HADOOP_PROCESSES_WITH_PORTS
-            while not accessible:
-                accessible = True
-                for node_ip, processes in six.iteritems(
-                        node_ip_list_with_node_processes):
-                    try:
-                        self.try_telnet(node_ip, '22')
-                    except Exception:
-                        accessible = False
+        node_count = 0
+        for node_ip, processes in node_ip_list_with_node_processes.items():
+            self.try_telnet(node_ip, '22')
+            node_count += 1
+            for process in processes:
+                if process in plugin_config.HADOOP_PROCESSES_WITH_PORTS:
+                    for i in range(self.common_config.TELNET_TIMEOUT * 60):
+                        try:
+                            time.sleep(1)
+                            telnetlib.Telnet(
+                                node_ip,
+                                plugin_config.HADOOP_PROCESSES_WITH_PORTS[
+                                    process]
+                            )
+                            break
 
-                    for process in processes:
-                        if process in proc_with_ports:
-                            try:
-                                self.try_telnet(node_ip,
-                                                proc_with_ports[process])
-                            except Exception:
-                                print('Connection attempt. NODE PROCESS: %s, '
-                                      'PORT: %s.' % (
-                                          process, proc_with_ports[process]))
-                                accessible = False
+                        except socket.error:
+                            print(
+                                'Connection attempt. NODE PROCESS: %s, '
+                                'PORT: %s.'
+                                % (process,
+                                   plugin_config.HADOOP_PROCESSES_WITH_PORTS[
+                                       process])
+                            )
 
-                if not accessible:
-                    time.sleep(1)
-
-        for node_ip, processes in six.iteritems(
-                node_ip_list_with_node_processes):
+                    else:
+                        self.try_telnet(
+                            node_ip,
+                            plugin_config.HADOOP_PROCESSES_WITH_PORTS[process]
+                        )
             if plugin_config.PROCESS_NAMES['tt'] in processes:
                 tasktracker_count += 1
             if plugin_config.PROCESS_NAMES['dn'] in processes:
                 datanode_count += 1
             if plugin_config.PROCESS_NAMES['nn'] in processes:
                 namenode_ip = node_ip
-
         return {
             'namenode_ip': namenode_ip,
             'tasktracker_count': tasktracker_count,
             'datanode_count': datanode_count,
-            'node_count': len(node_ip_list_with_node_processes)
+            'node_count': node_count
         }
 
     def await_active_workers_for_namenode(self, node_info, plugin_config):
-        self.open_ssh_connection(node_info['namenode_ip'])
-        timeout = self.common_config.HDFS_INITIALIZATION_TIMEOUT * 60
-        try:
-            with fixtures.Timeout(timeout, gentle=True):
-                while True:
-                    active_tasktracker_count = self.execute_command(
-                        'sudo -u %s bash -lc "hadoop job -list-active-trackers'
-                        '" | grep "^tracker_" | wc -l'
-                        % plugin_config.HADOOP_USER)[1]
-                    try:
-                        active_tasktracker_count = int(
-                            active_tasktracker_count)
-                    except ValueError:
-                        active_tasktracker_count = -1
-
-                    active_datanode_count = self.execute_command(
-                        'sudo -u %s bash -lc "hadoop dfsadmin -report" | '
-                        'grep -e "Datanodes available:.*" '
-                        '-e "Live datanodes.*" | grep -o "[0-9]*" | head -1'
-                        % plugin_config.HADOOP_USER)[1]
-                    try:
-                        active_datanode_count = int(active_datanode_count)
-                    except ValueError:
-                        active_datanode_count = -1
-
-                    if (active_tasktracker_count ==
-                            node_info['tasktracker_count'] and
-                            active_datanode_count ==
-                            node_info['datanode_count']):
-                        break
-
-                    time.sleep(10)
-
-        except fixtures.TimeoutException:
-            self.fail(
-                'Tasktracker or datanode cannot be started within '
-                '%s minute(s) for namenode.'
-                % self.common_config.HDFS_INITIALIZATION_TIMEOUT
-            )
-        finally:
-            self.close_ssh_connection()
-
-    def await_active_tasktracker(self, node_info, plugin_config):
-        self.open_ssh_connection(node_info['namenode_ip'])
+        self.open_ssh_connection(
+            node_info['namenode_ip'], plugin_config.SSH_USERNAME
+        )
         for i in range(self.common_config.HDFS_INITIALIZATION_TIMEOUT * 6):
             time.sleep(10)
             active_tasktracker_count = self.execute_command(
@@ -416,46 +315,28 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
                 '| grep "^tracker_" | wc -l'
                 % plugin_config.HADOOP_USER)[1]
             active_tasktracker_count = int(active_tasktracker_count)
-            if (active_tasktracker_count == node_info['tasktracker_count']):
+            active_datanode_count = int(
+                self.execute_command(
+                    'sudo -u %s bash -lc "hadoop dfsadmin -report" \
+                    | grep "Datanodes available:.*" | awk \'{print $3}\''
+                    % plugin_config.HADOOP_USER)[1])
+
+            if (
+                    active_tasktracker_count == node_info['tasktracker_count']
+            ) and (
+                    active_datanode_count == node_info['datanode_count']
+            ):
                 break
+
         else:
             self.fail(
                 'Tasktracker or datanode cannot be started within '
                 '%s minute(s) for namenode.'
-                % self.common_config.HDFS_INITIALIZATION_TIMEOUT)
+                % self.common_config.HDFS_INITIALIZATION_TIMEOUT
+            )
         self.close_ssh_connection()
 
-    @skip_test('TEST_EVENT_LOG',
-               'Testing event log was skipped until 0.7.8 client release')
-    @errormsg("Failure while event log testing: ")
-    def _test_event_log(self, cluster_id):
-        cluster = self.sahara.clusters.get(cluster_id)
-        events = self.sahara.events.list(cluster_id)
-
-        invalid_steps = []
-        if not events:
-            events = []
-
-        for step in cluster.provision_progress:
-            if not step['successful']:
-                invalid_steps.append(step)
-
-        if len(invalid_steps) > 0 or len(events) > 0:
-            events_info = "\n".join(six.text_type(e) for e in events)
-            invalid_steps_info = "\n".join(six.text_type(e)
-                                           for e in invalid_steps)
-            steps_info = "\n".join(six.text_type(e)
-                                   for e in cluster.provision_progress)
-            self.fail(
-                "Issues with event log work: "
-                "\n Not removed events: \n\n {events}"
-                "\n Incomplete steps: \n\n {invalid_steps}"
-                "\n All steps: \n\n {steps}".format(
-                    events=events_info,
-                    steps=steps_info,
-                    invalid_steps=invalid_steps_info))
-
-# --------------------------------Remote---------------------------------------
+#---------------------------------Remote---------------------------------------
 
     def connect_to_swift(self):
         return swift_client.Connection(
@@ -466,8 +347,8 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             auth_version=self.common_config.SWIFT_AUTH_VERSION
         )
 
-    def open_ssh_connection(self, host):
-        ssh_remote._connect(host, self._ssh_username, self.private_key)
+    def open_ssh_connection(self, host, ssh_username):
+        ssh_remote._connect(host, ssh_username, self.private_key)
 
     @staticmethod
     def execute_command(cmd):
@@ -485,19 +366,6 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
     def close_ssh_connection():
         ssh_remote._cleanup()
 
-    def transfer_helper_conf_file_to_node(self, file_name):
-        file = open('sahara/tests/integration/tests/resources/%s' % file_name
-                    ).read()
-        try:
-            self.write_file_to(file_name, file)
-
-        except Exception as e:
-            with excutils.save_and_reraise_exception():
-                print(
-                    '\nFailure while conf file transferring '
-                    'to cluster node: ' + six.text_type(e)
-                )
-
     def transfer_helper_script_to_node(self, script_name, parameter_list=None):
         script = open('sahara/tests/integration/tests/resources/%s'
                       % script_name).read()
@@ -512,20 +380,20 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             with excutils.save_and_reraise_exception():
                 print(
                     '\nFailure while helper script transferring '
-                    'to cluster node: ' + six.text_type(e)
+                    'to cluster node: ' + str(e)
                 )
         self.execute_command('chmod 777 script.sh')
 
-    def transfer_helper_script_to_nodes(self, node_ip_list, script_name,
-                                        parameter_list=None):
+    def transfer_helper_script_to_nodes(self, node_ip_list, ssh_username,
+                                        script_name, parameter_list=None):
         for node_ip in node_ip_list:
-            self.open_ssh_connection(node_ip)
+            self.open_ssh_connection(node_ip, ssh_username)
             self.transfer_helper_script_to_node(script_name, parameter_list)
             self.close_ssh_connection()
 
-# -------------------------------Helper methods--------------------------------
+#--------------------------------Helper methods--------------------------------
 
-    def get_image_id_and_ssh_username(self):
+    def get_image_id_and_ssh_username(self, plugin_config):
         def print_error_log(parameter, value):
             print(
                 '\nImage with %s "%s" was found in image list but it was '
@@ -535,7 +403,11 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
 
         def try_get_image_id_and_ssh_username(parameter, value):
             try:
-                return image.id, image.metadata[imgs.PROP_USERNAME]
+                if not plugin_config.SSH_USERNAME:
+                    return image.id, image.metadata[imgs.PROP_USERNAME]
+
+                else:
+                    return image.id, plugin_config.SSH_USERNAME
 
             except KeyError:
                 with excutils.save_and_reraise_exception():
@@ -544,42 +416,45 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
         images = self.nova.images.list()
         # If plugin_config.IMAGE_ID is not None then find corresponding image
         # and return its ID and username. If image not found then handle error
-        if self.plugin_config.IMAGE_ID:
+        if plugin_config.IMAGE_ID:
             for image in images:
-                if image.id == self.plugin_config.IMAGE_ID:
+                if image.id == plugin_config.IMAGE_ID:
                     return try_get_image_id_and_ssh_username(
-                        'ID', self.plugin_config.IMAGE_ID)
+                        'ID', plugin_config.IMAGE_ID
+                    )
             self.fail(
                 '\n\nImage with ID "%s" not found in image list. Please, make '
-                'sure you specified right image ID.\n' %
-                self.plugin_config.IMAGE_ID)
+                'sure you specified right image ID.\n' % plugin_config.IMAGE_ID
+            )
         # If plugin_config.IMAGE_NAME is not None then find corresponding image
         # and return its ID and username. If image not found then handle error
-        if self.plugin_config.IMAGE_NAME:
+        if plugin_config.IMAGE_NAME:
             for image in images:
-                if image.name == self.plugin_config.IMAGE_NAME:
+                if image.name == plugin_config.IMAGE_NAME:
                     return try_get_image_id_and_ssh_username(
-                        'name', self.plugin_config.IMAGE_NAME)
+                        'name', plugin_config.IMAGE_NAME
+                    )
             self.fail(
                 '\n\nImage with name "%s" not found in image list. Please, '
                 'make sure you specified right image name.\n'
-                % self.plugin_config.IMAGE_NAME)
+                % plugin_config.IMAGE_NAME
+            )
         # If plugin_config.IMAGE_TAG is not None then find corresponding image
         # and return its ID and username. If image not found then handle error
-        if self.plugin_config.IMAGE_TAG:
+        if plugin_config.IMAGE_TAG:
             for image in images:
                 if (image.metadata.get(imgs.PROP_TAG + '%s'
-                    % self.plugin_config.IMAGE_TAG)) and (
-                        image.metadata.get(imgs.PROP_TAG + str(
-                                           self.plugin_config.PLUGIN_NAME))):
+                    % plugin_config.IMAGE_TAG)) and (
+                        image.metadata.get(imgs.PROP_TAG + (
+                                           '%s' % plugin_config.PLUGIN_NAME))):
                     return try_get_image_id_and_ssh_username(
-                        'tag', self.plugin_config.IMAGE_TAG
+                        'tag', plugin_config.IMAGE_TAG
                     )
             self.fail(
                 '\n\nImage with tag "%s" not found in list of registered '
                 'images for Sahara. Please, make sure tag "%s" was added to '
                 'image and image was correctly registered.\n'
-                % (self.plugin_config.IMAGE_TAG, self.plugin_config.IMAGE_TAG)
+                % (plugin_config.IMAGE_TAG, plugin_config.IMAGE_TAG)
             )
         # If plugin_config.IMAGE_ID, plugin_config.IMAGE_NAME and
         # plugin_config.IMAGE_TAG are None then image is chosen
@@ -590,10 +465,14 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
         # If image with tag "sahara_i_tests" not found then handle error
         for image in images:
             if (image.metadata.get(imgs.PROP_TAG + 'sahara_i_tests')) and (
-                    image.metadata.get(imgs.PROP_TAG + str(
-                                       self.plugin_config.PLUGIN_NAME))):
+                    image.metadata.get(imgs.PROP_TAG + (
+                                       '%s' % plugin_config.PLUGIN_NAME))):
                 try:
-                    return image.id, image.metadata[imgs.PROP_USERNAME]
+                    if not plugin_config.SSH_USERNAME:
+                        return image.id, image.metadata[imgs.PROP_USERNAME]
+
+                    else:
+                        return image.id, plugin_config.SSH_USERNAME
 
                 except KeyError:
                         with excutils.save_and_reraise_exception():
@@ -651,37 +530,19 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
                     % self.common_config.INTERNAL_NEUTRON_NETWORK
                 )
 
-    def delete_cluster(self, cluster_id):
+    def delete_objects(self, cluster_id=None,
+                       cluster_template_id=None,
+                       node_group_template_id_list=None):
         if not self.common_config.RETAIN_CLUSTER_AFTER_TEST:
-            return self.delete_resource(self.sahara.clusters.delete,
-                                        cluster_id)
-
-    def delete_cluster_template(self, cluster_template_id):
-        if not self.common_config.RETAIN_CLUSTER_AFTER_TEST:
-            return self.delete_resource(self.sahara.cluster_templates.delete,
-                                        cluster_template_id)
-
-    def delete_node_group_template(self, node_group_template_id):
-        if not self.common_config.RETAIN_CLUSTER_AFTER_TEST:
-            return self.delete_resource(
-                self.sahara.node_group_templates.delete,
-                node_group_template_id)
-
-    def is_resource_deleted(self, method, *args, **kwargs):
-        try:
-            method(*args, **kwargs)
-        except client_base.APIException as ex:
-            return ex.error_code == 404
-
-        return False
-
-    def delete_resource(self, method, *args, **kwargs):
-        with fixtures.Timeout(self.common_config.DELETE_RESOURCE_TIMEOUT*60,
-                              gentle=True):
-            while True:
-                if self.is_resource_deleted(method, *args, **kwargs):
-                    break
-                time.sleep(5)
+            if cluster_id:
+                self.sahara.clusters.delete(cluster_id)
+            if cluster_template_id:
+                self.sahara.cluster_templates.delete(cluster_template_id)
+            if node_group_template_id_list:
+                for node_group_template_id in node_group_template_id_list:
+                    self.sahara.node_group_templates.delete(
+                        node_group_template_id
+                    )
 
     @staticmethod
     def delete_swift_container(swift, container):
@@ -697,7 +558,7 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             'ERROR LOG *!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*'
             '!*!\n'
         )
-        print(message + six.text_type(exception))
+        print(message + str(exception))
         print(
             '\n!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!* END OF '
             'ERROR LOG *!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*'
@@ -717,13 +578,9 @@ class ITestCase(testcase.WithAttributes, base.BaseTestCase):
             '!*!\n\n'
         )
 
-    @staticmethod
-    def rand_name(name):
-        return '%s-%s' % (name, uuidutils.generate_uuid()[:8])
-
     def tearDown(self):
         if not self.common_config.PATH_TO_SSH_KEY:
-            self.nova.keypairs.delete(self.user_keypair_id)
+            self.nova.keypairs.delete(self.common_config.USER_KEYPAIR_ID)
         if not self.common_config.FLAVOR_ID:
             self.nova.flavors.delete(self.flavor_id)
 
