@@ -14,15 +14,15 @@
 # under the License.
 
 import sys
-from unittest import mock
 
+import mock
 import testscenarios
-import testtools
+import unittest2
 
 from sahara.db.migration import cli
 
 
-class TestCli(testtools.TestCase):
+class TestCli(unittest2.TestCase):
     func_name = ''
     exp_args = ()
     exp_kwargs = {}
@@ -65,7 +65,19 @@ class TestCli(testtools.TestCase):
          dict(argv=['prog', 'upgrade', '--delta', '3'],
               func_name='upgrade',
               exp_args=('+3',),
-              exp_kwargs={'sql': False}))
+              exp_kwargs={'sql': False})),
+
+        ('downgrade-sql',
+         dict(argv=['prog', 'downgrade', '--sql', 'folsom'],
+              func_name='downgrade',
+              exp_args=('folsom',),
+              exp_kwargs={'sql': True})),
+
+        ('downgrade-delta',
+         dict(argv=['prog', 'downgrade', '--delta', '2'],
+              func_name='downgrade',
+              exp_args=('-2',),
+              exp_kwargs={'sql': False})),
     ]
 
     def setUp(self):
