@@ -13,17 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import unittest2
+
 from sahara.plugins.hdp.versions import versionhandlerfactory
-from sahara.tests.unit import base
 
 
-class VersionManagerFactoryTest(base.SaharaTestCase):
+class VersionManagerFactoryTest(unittest2.TestCase):
 
     def test_get_versions(self):
         factory = versionhandlerfactory.VersionHandlerFactory.get_instance()
         versions = factory.get_versions()
 
-        self.assertEqual(1, len(versions))
+        self.assertEqual(2, len(versions))
+        self.assertIn('1.3.2', versions)
         self.assertIn('2.0.6', versions)
 
     def test_get_version_handlers(self):
