@@ -14,15 +14,16 @@
 # limitations under the License.
 
 import mock
+
 from novaclient import exceptions as nova_exceptions
+import six
 
 from sahara import conductor as cond
 from sahara import context
 from sahara.service import direct_engine as e
-from sahara.service import ops
 from sahara.tests.unit import base
-from sahara.utils import cluster as cluster_utils
-from sahara.utils import crypto as c
+import sahara.utils.crypto as c
+from sahara.utils import general as g
 
 
 conductor = cond.API
@@ -41,9 +42,6 @@ class AbstractInstanceTest(base.SaharaWithDbTestCase):
         self.novaclient_patcher = mock.patch(
             'sahara.utils.openstack.nova.client')
         self.nova = _create_nova_mock(self.novaclient_patcher.start())
-        self.nova.server_groups.findall.return_value = []
-        self.nova.floating_ips.findall.__name__ = 'findall'
-        self.nova.floating_ips.delete.__name__ = 'delete'
 
         self.get_userdata_patcher = mock.patch(
             'sahara.utils.remote.get_userdata_template')
@@ -59,76 +57,58 @@ class AbstractInstanceTest(base.SaharaWithDbTestCase):
 
 class TestClusterRollBack(AbstractInstanceTest):
 
-    @mock.patch('sahara.service.direct_engine.DirectEngine._check_if_deleted')
-    @mock.patch('sahara.service.ops._prepare_provisioning')
-    @mock.patch('sahara.service.ops.INFRA')
-    def test_cluster_creation_with_errors(self, infra, prepare,
-                                          deleted_checker):
-        infra.create_cluster.side_effect = self.engine.create_cluster
-        infra.rollback_cluster.side_effect = self.engine.rollback_cluster
-
+    def test_cluster_creation_with_errors(self):
         node_groups = [_make_ng_dict('test_group', 'test_flavor',
                                      ['data node', 'task tracker'], 2)]
 
         cluster = _create_cluster_mock(node_groups, [])
 
-        prepare.return_value = (context.ctx(), cluster, mock.Mock())
-
         self.nova.servers.create.side_effect = [_mock_instance(1),
                                                 MockException("test")]
 
         self.nova.servers.list.return_value = [_mock_instance(1)]
 
-        deleted_checker.return_value = True
-
-        ops._provision_cluster(cluster.id)
+        with self.assertRaises(MockException):
+            self.engine.create_cluster(cluster)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
-        self.assertEqual(0, len(cluster_obj.node_groups[0].instances))
+        self.assertEqual(len(cluster_obj.node_groups[0].instances), 0)
 
 
 class NodePlacementTest(AbstractInstanceTest):
 
     def test_one_node_groups_and_one_affinity_group(self):
-        self.nova.server_groups.create.return_value = mock.Mock(id='123')
-
         node_groups = [_make_ng_dict('test_group', 'test_flavor',
                                      ['data node'], 2)]
         cluster = _create_cluster_mock(node_groups, ["data node"])
         self.engine._create_instances(cluster)
         userdata = _generate_user_data_script(cluster)
+
         self.nova.servers.create.assert_has_calls(
             [mock.call("test_cluster-test_group-001",
                        "initial",
                        "test_flavor",
-                       scheduler_hints={'group': "123"},
+                       scheduler_hints=None,
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None),
+                       key_name='user_keypair'),
              mock.call("test_cluster-test_group-002",
                        "initial",
                        "test_flavor",
-                       scheduler_hints={'group': "123"},
+                       scheduler_hints={'different_host': ["1"]},
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None)],
+                       key_name='user_keypair')],
             any_order=False)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
-        self.assertEqual(2, len(cluster_obj.node_groups[0].instances))
+        self.assertEqual(len(cluster_obj.node_groups[0].instances), 2)
 
     def test_one_node_groups_and_no_affinity_group(self):
-        self.nova.server_groups.create.return_value = mock.Mock(id='123')
-
         node_groups = [_make_ng_dict('test_group', 'test_flavor',
                                      ['data node', 'task tracker'], 2)]
 
         cluster = _create_cluster_mock(node_groups, [])
-
         self.engine._create_instances(cluster)
         userdata = _generate_user_data_script(cluster)
 
@@ -138,26 +118,20 @@ class NodePlacementTest(AbstractInstanceTest):
                        "test_flavor",
                        scheduler_hints=None,
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None),
+                       key_name='user_keypair'),
              mock.call("test_cluster-test_group-002",
                        "initial",
                        "test_flavor",
                        scheduler_hints=None,
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None)],
+                       key_name='user_keypair')],
             any_order=False)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
-        self.assertEqual(2, len(cluster_obj.node_groups[0].instances))
+        self.assertEqual(len(cluster_obj.node_groups[0].instances), 2)
 
     def test_two_node_groups_and_one_affinity_group(self):
-        self.nova.server_groups.create.return_value = mock.Mock(id='123')
-
         node_groups = [_make_ng_dict("test_group_1", "test_flavor",
                                      ["data node", "test tracker"], 2),
                        _make_ng_dict("test_group_2", "test_flavor",
@@ -167,38 +141,69 @@ class NodePlacementTest(AbstractInstanceTest):
         self.engine._create_instances(cluster)
         userdata = _generate_user_data_script(cluster)
 
+        def _find_created_at(idx):
+            """Find the #N instance creation call.
+
+            To determine which instance was created first, we should check
+            scheduler hints For example we should find call with scheduler
+            hint different_hosts = [1, 2] and it's the third call of instance
+            create.
+            """
+            different_hosts = []
+            for instance_id in six.moves.xrange(1, idx):
+                different_hosts.append(str(instance_id))
+            scheduler_hints = ({'different_host': different_hosts}
+                               if different_hosts else None)
+
+            for call in self.nova.servers.create.mock_calls:
+                if call[2]['scheduler_hints'] == scheduler_hints:
+                    return call[1][0]
+
+            self.fail("Couldn't find call with scheduler_hints='%s'"
+                      % scheduler_hints)
+
+        # find instance names in instance create calls
+        instance_names = []
+        for idx in six.moves.xrange(1, 4):
+            instance_name = _find_created_at(idx)
+            if instance_name in instance_names:
+                self.fail("Create instance was called twice with the same "
+                          "instance name='%s'" % instance_name)
+            instance_names.append(instance_name)
+
+        self.assertEqual(3, len(instance_names))
+        self.assertItemsEqual([
+            'test_cluster-test_group_1-001',
+            'test_cluster-test_group_1-002',
+            'test_cluster-test_group_2-001',
+        ], instance_names)
+
         self.nova.servers.create.assert_has_calls(
-            [mock.call('test_cluster-test_group_1-001',
+            [mock.call(instance_names[0],
                        "initial",
                        "test_flavor",
-                       scheduler_hints={'group': "123"},
+                       scheduler_hints=None,
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None),
-             mock.call('test_cluster-test_group_1-002',
+                       key_name='user_keypair'),
+             mock.call(instance_names[1],
                        "initial",
                        "test_flavor",
-                       scheduler_hints={'group': "123"},
+                       scheduler_hints={'different_host': ["1"]},
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None),
-             mock.call('test_cluster-test_group_2-001',
+                       key_name='user_keypair'),
+             mock.call(instance_names[2],
                        "initial",
                        "test_flavor",
-                       scheduler_hints={'group': "123"},
+                       scheduler_hints={'different_host': ["1", "2"]},
                        userdata=userdata,
-                       key_name='user_keypair',
-                       security_groups=None,
-                       availability_zone=None)],
+                       key_name='user_keypair')],
             any_order=False)
 
         ctx = context.ctx()
         cluster_obj = conductor.cluster_get_all(ctx)[0]
         inst_number = len(cluster_obj.node_groups[0].instances)
         inst_number += len(cluster_obj.node_groups[1].instances)
-        self.assertEqual(3, inst_number)
+        self.assertEqual(inst_number, 3)
 
 
 class IpManagementTest(AbstractInstanceTest):
@@ -220,41 +225,35 @@ class IpManagementTest(AbstractInstanceTest):
         self.engine._create_instances(cluster)
 
         cluster = conductor.cluster_get(ctx, cluster)
-        instances_list = cluster_utils.get_instances(cluster)
+        instances_list = g.get_instances(cluster)
 
         self.engine._assign_floating_ips(instances_list)
 
         self.nova.floating_ips.create.assert_has_calls(
             [mock.call("pool"), mock.call("pool")])
 
-        self.assertEqual(2, self.nova.floating_ips.create.call_count,
+        self.assertEqual(self.nova.floating_ips.create.call_count, 2,
                          "Not expected floating IPs number found.")
 
 
 class ShutdownClusterTest(AbstractInstanceTest):
-
-    @mock.patch('sahara.service.direct_engine.DirectEngine._check_if_deleted')
-    @mock.patch('sahara.service.direct_engine.DirectEngine.'
-                '_map_security_groups')
-    def test_delete_floating_ips(self, map_mock, deleted_checker):
+    def test_delete_floating_ips(self):
         node_groups = [_make_ng_dict("test_group_1", "test_flavor",
                                      ["data node", "test tracker"], 2, 'pool')]
-        map_mock.return_value = []
+
         ctx = context.ctx()
         cluster = _create_cluster_mock(node_groups, ["datanode"])
         self.engine._create_instances(cluster)
 
         cluster = conductor.cluster_get(ctx, cluster)
-        instances_list = cluster_utils.get_instances(cluster)
+        instances_list = g.get_instances(cluster)
 
         self.engine._assign_floating_ips(instances_list)
 
-        deleted_checker.return_value = True
-
         self.engine._shutdown_instances(cluster)
-        self.assertEqual(2, self.nova.floating_ips.delete.call_count,
+        self.assertEqual(self.nova.floating_ips.delete.call_count, 2,
                          "Not expected floating IPs number found in delete")
-        self.assertEqual(2, self.nova.servers.delete.call_count,
+        self.assertEqual(self.nova.servers.delete.call_count, 2,
                          "Not expected")
 
 
@@ -321,8 +320,6 @@ def _mock_ips(count):
 def _generate_user_data_script(cluster):
     script_template = """#!/bin/bash
 echo "%(public_key)s" >> %(user_home)s/.ssh/authorized_keys\n
-# ====== COMMENT OUT Defaults requiretty in /etc/sudoers ========
-sed '/^Defaults    requiretty*/ s/^/#/' -i /etc/sudoers\n
 """
     return script_template % {
         "public_key": cluster.management_public_key,
