@@ -13,10 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
 
 import jsonschema
-from oslo_utils import uuidutils
-import testtools
+import six
+import unittest2
 
 from sahara.utils import api_validator
 
@@ -26,7 +27,7 @@ def _validate(schema, data):
     validator.validate(data)
 
 
-class ApiValidatorTest(testtools.TestCase):
+class ApiValidatorTest(unittest2.TestCase):
     def _validate_success(self, schema, data):
         return _validate(schema, data)
 
@@ -150,10 +151,10 @@ class ApiValidatorTest(testtools.TestCase):
             "format": "uuid",
         }
 
-        id = uuidutils.generate_uuid()
+        id = six.text_type(uuid.uuid4())
 
         self._validate_success(schema, id)
-        self._validate_success(schema, id.replace("-", ""))
+        self._validate_failure(schema, id.replace("-", ""))
 
     def test_validate_valid_name(self):
         schema = {
@@ -168,11 +169,11 @@ class ApiValidatorTest(testtools.TestCase):
         self._validate_failure(schema, "_123")
         self._validate_success(schema, "a" * 64)
         self._validate_failure(schema, "")
-        self._validate_success(schema, "hadoop-examples-2.6.0.jar")
-        self._validate_success(schema, "hadoop-examples-2.6.0")
-        self._validate_success(schema, "hadoop-examples-2.6.0.")
-        self._validate_success(schema, "1")
-        self._validate_success(schema, "1a")
+        self._validate_success(schema, "hadoop-examples-1.2.1.jar")
+        self._validate_success(schema, "hadoop-examples-1.2.1")
+        self._validate_success(schema, "hadoop-examples-1.2.1.")
+        self._validate_failure(schema, "1")
+        self._validate_failure(schema, "1a")
         self._validate_success(schema, "a1")
         self._validate_success(schema, "A1")
         self._validate_success(schema, "A1B")
@@ -181,43 +182,6 @@ class ApiValidatorTest(testtools.TestCase):
         self._validate_success(schema, "a._.b")
         self._validate_success(schema, "a_")
         self._validate_success(schema, "a-b-001")
-        self._validate_failure(schema, "-aaaa-bbbb")
-        self._validate_failure(schema, ".aaaa-bbbb")
-
-        self._validate_failure(schema, None)
-        self._validate_failure(schema, 1)
-        self._validate_failure(schema, ["1"])
-
-    def test_validate_valid_keypair_name(self):
-        schema = {
-            "type": "string",
-            "format": "valid_keypair_name",
-        }
-
-        self._validate_success(schema, "abcd")
-        self._validate_success(schema, "abcd123")
-        self._validate_success(schema, "abcd-123")
-        self._validate_success(schema, "abcd_123")
-        self._validate_success(schema, "_123")
-        self._validate_success(schema, "a" * 64)
-        self._validate_failure(schema, "")
-        self._validate_failure(schema, "hadoop-examples-2.6.0.jar")
-        self._validate_failure(schema, "hadoop-examples-2.6.0")
-        self._validate_failure(schema, "hadoop-examples-2.6.0.")
-        self._validate_success(schema, "1")
-        self._validate_success(schema, "1a")
-        self._validate_success(schema, "a1")
-        self._validate_success(schema, "A1")
-        self._validate_success(schema, "A1B")
-        self._validate_failure(schema, "a.b")
-        self._validate_failure(schema, "a..b")
-        self._validate_failure(schema, "a._.b")
-        self._validate_success(schema, "a_")
-        self._validate_success(schema, "a-b-001")
-        self._validate_success(schema, "-aaaa-bbbb")
-        self._validate_success(schema, "-aaaa bbbb")
-        self._validate_success(schema, " -aaaa bbbb")
-        self._validate_failure(schema, ".aaaa-bbbb")
 
         self._validate_failure(schema, None)
         self._validate_failure(schema, 1)
@@ -227,7 +191,6 @@ class ApiValidatorTest(testtools.TestCase):
         schema = {
             "type": "string",
             "format": "valid_name_hostname",
-            "minLength": 1,
         }
 
         self._validate_success(schema, "abcd")
@@ -237,9 +200,9 @@ class ApiValidatorTest(testtools.TestCase):
         self._validate_failure(schema, "_123")
         self._validate_success(schema, "a" * 64)
         self._validate_failure(schema, "")
-        self._validate_failure(schema, "hadoop-examples-2.6.0.jar")
-        self._validate_failure(schema, "hadoop-examples-2.6.0")
-        self._validate_failure(schema, "hadoop-examples-2.6.0.")
+        self._validate_failure(schema, "hadoop-examples-1.2.1.jar")
+        self._validate_failure(schema, "hadoop-examples-1.2.1")
+        self._validate_failure(schema, "hadoop-examples-1.2.1.")
         self._validate_failure(schema, "1")
         self._validate_failure(schema, "1a")
         self._validate_success(schema, "a1")
@@ -259,7 +222,7 @@ class ApiValidatorTest(testtools.TestCase):
     def test_validate_hostname(self):
         schema = {
             "type": "string",
-            "format": "idn-hostname",
+            "format": "hostname",
         }
 
         self._validate_success(schema, "abcd")
@@ -337,7 +300,7 @@ class ApiValidatorTest(testtools.TestCase):
         self._validate_success(schema, 1)
         self._validate_success(schema, "0")
         self._validate_success(schema, "1")
-        self._validate_success(schema, uuidutils.generate_uuid())
+        self._validate_success(schema, six.text_type(uuid.uuid4()))
         self._validate_failure(schema, True)
         self._validate_failure(schema, 0.1)
         self._validate_failure(schema, "0.1")
