@@ -18,33 +18,38 @@ import xml.dom.minidom as xml
 
 import pkg_resources as pkg
 
+from sahara import version
 
-# hadoop.xml related utils
 
-def load_hadoop_xml_defaults(file_name, package='sahara'):
-    doc = load_xml_document(file_name, package=package)
+## hadoop.xml related utils
+
+def load_hadoop_xml_defaults(file_name):
+    doc = load_xml_document(file_name)
     configs = []
     prop = doc.getElementsByTagName('property')
     for elements in prop:
         configs.append({
-            "name": get_text_from_node(elements, 'name'),
-            "value": _adjust_field(get_text_from_node(elements, 'value')),
+            "name": _get_text_from_node(elements, 'name'),
+            "value": _adjust_field(_get_text_from_node(elements, 'value')),
             "description": _adjust_field(
-                get_text_from_node(elements, 'description'))
+                _get_text_from_node(elements, 'description'))
         })
     return configs
 
 
-def parse_hadoop_xml_with_name_and_value(data):
-    doc = xml.parseString(data)
+def load_hadoop_xml_defaults_with_type_and_locale(file_name):
+    doc = load_xml_document(file_name)
     configs = []
     prop = doc.getElementsByTagName('property')
     for elements in prop:
         configs.append({
-            'name': get_text_from_node(elements, 'name'),
-            'value': get_text_from_node(elements, 'value')
+            'name': _get_text_from_node(elements, 'name'),
+            'value': _get_text_from_node(elements, 'value'),
+            'type': _get_text_from_node(elements, 'valuetype'),
+            'description': _adjust_field(
+                _get_text_from_node(
+                    _get_node_element(elements, 'description'), 'en'))
         })
-
     return configs
 
 
@@ -69,29 +74,19 @@ def create_hadoop_xml(configs, config_filter=None):
     if config_filter is not None:
         default_configs = [cfg['name'] for cfg in config_filter]
 
-    for name in sorted(configs):
+    for name, value in configs.items():
         if name in default_configs or config_filter is None:
-            add_property_to_configuration(doc, name, configs[name])
+            add_property_to_configuration(doc, name, value)
 
     # Return newly created XML
     return doc.toprettyxml(indent="  ")
 
 
-def create_elements_xml(configs):
-    doc = xml.Document()
-    text = ''
-    for name in sorted(configs):
-        element = doc.createElement('property')
-        add_text_element_to_element(doc, element, 'name', name)
-        add_text_element_to_element(doc, element, 'value', configs[name])
-        text += element.toprettyxml(indent="  ")
-    return text
+## basic utils
 
-
-# basic utils
-
-def load_xml_document(file_name, strip=False, package='sahara'):
-    fname = pkg.resource_filename(package, file_name)
+def load_xml_document(file_name, strip=False):
+    fname = pkg.resource_filename(
+        version.version_info.package, file_name)
     if strip:
         with open(fname, "r") as f:
             doc = "".join(line.strip() for line in f)
@@ -100,7 +95,7 @@ def load_xml_document(file_name, strip=False, package='sahara'):
         return xml.parse(fname)
 
 
-def get_text_from_node(element, name):
+def _get_text_from_node(element, name):
     element = element.getElementsByTagName(name) if element else None
     return element[0].firstChild.nodeValue if (
         element and element[0].hasChildNodes()) else ''
@@ -118,8 +113,9 @@ def add_property_to_configuration(doc, name, value):
 
 def add_properties_to_configuration(doc, parent_for_conf, configs):
     get_and_create_if_not_exist(doc, parent_for_conf, 'configuration')
-    for n in sorted(filter(lambda x: x, configs)):
-        add_property_to_configuration(doc, n, configs[n])
+    for n, v in configs.items():
+        if n:
+            add_property_to_configuration(doc, n, v)
 
 
 def add_child(doc, parent, tag_to_add):
@@ -148,45 +144,16 @@ def add_text_element_to_tag(doc, parent_tag, element, value):
 
 def add_text_element_to_element(doc, parent, element, value):
     parent.appendChild(doc.createElement(element))
-    try:
-        parent.lastChild.appendChild(doc.createTextNode(str(value)))
-    except UnicodeEncodeError:
-        parent.lastChild.appendChild(doc.createTextNode(
-            str(value.encode('utf8'))))
+    parent.lastChild.appendChild(doc.createTextNode(str(value)))
 
 
 def add_equal_separated_dict(doc, parent_tag, each_elem_tag, value):
-    for k in sorted(filter(lambda x: x, value)):
+    for k, v in value.items():
         if k:
             add_text_element_to_tag(doc, parent_tag, each_elem_tag,
-                                    "%s=%s" % (k, value[k]))
-
-
-def add_attributes_to_element(doc, tag, attributes):
-    element = doc.getElementsByTagName(tag)[0]
-    for name, value in attributes.items():
-        element.setAttribute(name, value)
+                                    "%s=%s" % (k, v))
 
 
 def add_tagged_list(doc, parent_tag, each_elem_tag, values):
     for v in values:
         add_text_element_to_tag(doc, parent_tag, each_elem_tag, v)
-
-
-def get_property_dict(elem):
-    res = {}
-    properties = elem.getElementsByTagName('property')
-    for prop in properties:
-        k = get_text_from_node(prop, 'name')
-        v = get_text_from_node(prop, 'value')
-        res[k] = v
-    return res
-
-
-def get_param_dict(elem):
-    res = {}
-    params = elem.getElementsByTagName('param')
-    for param in params:
-        k, v = param.firstChild.nodeValue.split('=')
-        res[k] = v
-    return res
